@@ -1,6 +1,6 @@
 /*
  * libusb_wrap.c
- * $Id: libusb_wrap.c,v 1.9 2007-06-29 14:40:49 rousseau Exp $
+ * $Id: libusb_wrap.c,v 1.24 2012/04/08 19:09:46 rousseau Exp $
  * USB access routines using the libusb library
  *
  * Created by Ludovic Rousseau on Sep 27 2002
@@ -9,7 +9,7 @@
  */
 
 #include <stdio.h>
-#include <string.h> 
+#include <string.h>
 #include <errno.h>
 #include <usb.h>
 
@@ -39,9 +39,9 @@ typedef struct
 } _usbID;
 
 /*
- * Add an entry to match your reader. 
+ * Add an entry to match your reader.
  */
-static _usbID UsbIDs[] = 
+static _usbID UsbIDs[] =
 {
 	{ 0x08E6, 0x0430 }, /* GemPC 430 */
 	{ 0x08E6, 0x0432 },	/* GemPC 432 */
@@ -90,7 +90,7 @@ status_t OpenUSB(DWORD lun, LPSTR device)
 	struct usb_dev_handle *dev_handle;
 	int device_vendor, device_product;
 
-	DEBUG_COMM3("Lun: %X, Device: %s", lun, device);
+	DEBUG_COMM3("Lun: %lX, Device: %s", lun, device);
 
 	/* device name specified */
 	if (device)
@@ -126,7 +126,7 @@ status_t OpenUSB(DWORD lun, LPSTR device)
 	/* is the lun already used? */
 	if (usbDevice[reader].handle != NULL)
 	{
-		DEBUG_CRITICAL2("USB driver with lun %X already in use", lun);
+		DEBUG_CRITICAL2("USB driver with lun %lX already in use", lun);
 		return STATUS_UNSUCCESSFUL;
 	}
 
