@@ -11,7 +11,7 @@
 #ifndef _LIBUSB_WRAP_
 #define _LIBUSB_WRAP_
 
-status_t OpenUSB( DWORD lun, LPTSTR device );
+status_t OpenUSB( DWORD lun, LPSTR device );
 status_t WriteUSB( DWORD lun, DWORD length, unsigned char *Buffer );
 status_t ReadUSB( DWORD lun, DWORD *length, unsigned char *Buffer );
 status_t CloseUSB( DWORD lun );
